#ifndef _CEGOCOMPARISON_H_INCLUDED_
#define _CEGOCOMPARISON_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoComparison.h
// ----------------
// Cego Comparison enum definition 
//      
// Design and Implementation by Bjoern Lemke
//
// (C)opyright 2000-2025 Bjoern Lemke
//
// INTERFACE MODULE
//
// Class: CegoComparison
// 
// Description: Logical comparison operators
//
// Status: CLEAN
//
///////////////////////////////////////////////////////////////////////////////

enum CegoComparison { EQUAL, LESS_THAN, MORE_THAN, LESS_EQUAL_THAN, MORE_EQUAL_THAN, NOT_EQUAL };

#endif
